darkhistory.physics.omega_rad — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.omega_rad

`darkhistory.physics.` `omega_rad` = 8e-05

  Omega of radiation today.

#### Previous topic

darkhistory.physics.omega_m

#### Next topic

darkhistory.physics.omega_lambda

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.